bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 32. Aventiure
___________________________________________________ #### <Wie Bloedelin erslagen wart>
| ### loedelins reken die warn alle gar ### mit tvsent halspergen hvoben si sich dar ### da Dancwart mit den knehten ob den tischen saz ### da hvop sich vnder helden der aller groziste haz
###### 1859 | ### Also der herre Bloedel fvr die tische gie ### Dancwart der marschalch in vlizeclich enphie ### willekomen her ze hvse min her Bloedelin ### ia wundert mich der mere waz sol disiv rede sin
###### 1860 | ### Ia darftv mich niht grvezen so sprach Bloedelin ### wan komen min mvoz din ende sin ### dvrch Hagnen dinen brvoder der Sifriden slvoch ### des enkiltest dv zen Hvnen vn– ander degne genvoc
###### 1861 | ### Neina herre Bloedel sprach do Dancwart ### so moeht vns balde riwen disiv hovevart ### ich waz ein wenich kindel do Sifrit vloz den lip ### ich weiz niht waz mir wizet des kvnic Eceln wip
###### 1862 | ### la enweiz ich dir der mere niht me ze sagen ### ez taten dine mage Gvnther vn– Hagne ### nv wert ich vil ellenden ir kvnnet niht genesen ### ir mvezet mit dem tode phant Kriemhilde wesen
###### 1863 | ### So enwelt ir niht erwinden sprach Dancwart ### so riwet mich min vlegen daz were baz gespart ### der snelle degne kvene von dem tische spranch ### er zoch ein scharfez wafen daz waz michel vn– lanch
###### 1864 | ### Do slvog er Bloedeline einen swindent swertes slach ### daz im daz hovbet schiere vor den fvezen lach [76a] ### daz si din morgengabe sprach Dancwart der degne ### zvo Nvodunges brvte der dv mit minne woldest phlegen
###### 1865 | ### Man mach si morgen meheln einen andern man ### wil er die brvtmiete dem wirt alsam getan ### ein vil getriwer Hvne hete im daz geseit ### daz in div kvnigin riet so grozlichiv lait
###### 1866 | ### Do sahen Bloedelins man ir herre la erslagen ### do wolden si den gesten niht langer daz vertragen ### mit vf erbvrten swerten si sprvngen fvr div kint ### in grimmen mvote daz gerov vil manigen sint
###### 1867 | ### Lvte rief do Dancwart daz gesinde allez an ### ir sehet wol edel knehte wie ez vmb vns wil gan ### nv wert ivch ellenden deswar des gat vns not ### swie vns die edle Kriemhilt so rehte gvetlich enpot
###### 1868 | ### Die niht swert heten die reihten fvr die banch ### vn– hvoben von den fvezen manigen schamel lanch ### der Bvrgonden knehte wolden niht vertragen ### da wart von swern stveln bvln harte vil geslagen
###### 1869 | ### Wie grimme sich do werten div ellenden kint ### si triwen vz dem hvse die gewafenden sint ### doch beleip ir tot darinne fvnf hvndert <oder> baz ### do waz daz ingesinde von blvote rot vn– naz
###### 1870 | ### Disiv starchen mere wurden dan geseit ### Eceln reken ez waz in grimme leit ### daz erslagen were Bloedel vn– sine man ### daz hete Hagnen brvoder mit den knehten getan
###### 1871 | ### E ez der kvnic erfvnde die Hvnen dvrh ir haz ### der garten sich zwai tvsent oder dannoch baz ### si giengen z den knehten daz mvoz et also wesen ### vn– liezen des gesindes inndert einen genesen
###### 1872 | ### Die vngetriwen brahten fvrz hvs ein michel her ### die ellenden knehte stvonden wol ze wer ### waz half ir baldez eilen si mvosen ligen tot ### darnach in kvrzen stvnden sich hvop ein vreislicher not
###### 1873 | ### Hie mvget ir hoem wunder bi vngefvoge sagen ### nivn tvsent knehte die lagen tot erslagen ### darvber ritter zwelfe der Dancwartes man ### man sach in alterseine noch bi den vienden stan
###### 1874 | ### Der schal was geswiftet der doz waz gelegen ### do blicte vber ahsel Dancwart der degn ### er sprach owe der vrivnde die ich verlorn han ### nv mvoz ich leider eine bi minen vienden stan
###### 1875 | ### Div swert genote vieln vf sin eins lip ### daz mvose sit beweinen vil maniges heldes wip ### den schilt den rvcte er hoher den vezzel nider baz ### do vrumte er vil der ringe von blvote vliezende naz
###### 1876 | ### So we mir dirre leide sprach Aldrians kint ### nv wichet Hvnen reken ir lat mich an den wint ### daz der lvft erkvele mich stvrmmveden man [76b] ### do sach man den reken vil harte vroelichen gan
###### 1877 | ### Also der stritemvede vz dem hvse spat ### waz iteniwer swerte vf seim helme erklanch ### die niht gesehen heten waz wunders tet sin hant ### die sprvngen enkegne hin von dem Bvrgonden lant
###### 1878 | ### Nv wolde got sprach Dancwart moeht ich den boten han ### der minen brvoder Hagnen kvnde wizzen lan ### daz ich vor disen reken sten in soelher not ### er hvlfe mir von hinnen oder er gelege bi mir tot
###### 1879 | ### Do sprachen Hvnen reken der bote mvostv sin ### so wir dich tragen toten fvr den brvoder din ### so silhet im erste leide der Gvnthers man ### dv hast dem kvnige Ecele so grozen schaden hie getan
###### 1880 | ### Er sprach nv lat daz dron vn– wihet hoher baz ### ia getvon ich eteslichem noh die ringe naz ### ich wil div mere selbe hin ze hove sagen ### vn– wil ovch minen herren minen grozen kvmber klagen
###### 1881 | ### Er leidete sich so sere den Eceln man ### daz si in mit den swerten torsten niht hestan ### do schvzzen si der gere so vil in sinen rant ### daz er in dvrch die swere mvose lazen von der hant
###### 1882 | ### Do wandens in betwingen do er niht schildes trvoch ### hei waz er tiefer wunden dvrch die helme slvoch ### des mvose vor im striche manich kvener man ### darvmbe lop vil grozen der kvene Dancwart gewan
###### 1883 | ### Ze beiden sinen siten sprvngen si im zvo ### ia kom ir eteslicher in den strit ze vrvo ### do gie er vor den vienden alsam ein eberswin ### ze walde tvot vor hvnden wie moht er kvener gesein
###### 1884 | ### Sin vart <div> wart erniwet von heizem blvote naz ### wie kvnd ein einich reke gestriten immer baz ### mit sinen vinden dann er hete getan ### man sach Hagnen brvoder ze hove herlichen gan
###### 1885 | ### Trvhsatze vn– schenchen die horten swerte klanch ### vil maniger do daz trinchen von der hende swanch ### vn– eteliche spise die man ze hove trvoch ### do kom im vor der stiegen der starken viende genvoch
###### 1886 | ### Wie nv ir trvhsetzen sprach der mvede degne ### ia soldet ir der geste vil gvetlichen phlegen ### vn– soldet den herren gvote spise tragen ### vn– liezet mich div mere minen lieben herren sagen
###### 1887 | ### Swelher dvrch sein eilen im fvr die stiegen spranch ### der slvog er etelichen so sweren swertes swanch ### daz si dvrch die vorhte vf hoher mvosen stan ### ez het sin starchez ellen vil michel wunders getan

<<< Übersicht <<< vorige Seite nächste Seite >>>